@@ -3,21 +3,10 @@ import stat
 import sys
 import os
 from os.path import exists
+from ._ffi import ffi
 
 PY3 = sys.version_info >= (3,)
 
-if not PY3:
-    ModuleNotFoundError = ImportError
-
-try:
-    from ._ffi import ffi
-except ModuleNotFoundError as e:
-    msg = "\nIt is likely caused by a broken installation of this package."
-    msg += "\nPlease, make sure you have a C compiler and try to uninstall"
-    msg += "\nand reinstall the package again."
-    e.msg = e.msg + msg
-    raise e
-
 if not PY3:
     FileNotFoundError = IOError
 
